##  Courses on SAP Learning: Links
Find links to courses on SAP Learning in the table below.
Section | Learning Journeys | Subscription Level
---|---|---
Practitioner Level 1 and 2 (now merged into one comprehensive learning journey)  | [Learning to Use the LeanIX Tool for Successful Enterprise Architecture​​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Flearning-journeys%2Flearning-to-use-the-leanix-tool-for-successful-enterprise-architecture "https://learning.sap.com/learning-journeys/learning-to-use-the-leanix-tool-for-successful-enterprise-architecture") | Free
SAP LeanIX Certification | [SAP Certified Associate - Enterprise Architecture Consultant - SAP LeanIX![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcertifications%2Fsap-certified-associate-enterprise-architecture-consultant-sap-leanix "https://learning.sap.com/certifications/sap-certified-associate-enterprise-architecture-consultant-sap-leanix")​ | Subscription required
SAP LeanIX Onboarding  | [Getting Started with Your SAP LeanIX Onboarding![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fgetting-started-with-your-sap-leanix-onboarding "https://learning.sap.com/courses/getting-started-with-your-sap-leanix-onboarding")​​ | Free
[Adding First Data to Your SAP LeanIX Workspace​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fadding-first-data-to-your-sap-leanix-workspace "https://learning.sap.com/courses/adding-first-data-to-your-sap-leanix-workspace") | Free
[Getting Your Stakeholders on Board, Enriching Data and Taking First Decisions![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fgetting-your-stakeholders-on-board-enriching-data-and-taking-first-decisions "https://learning.sap.com/courses/getting-your-stakeholders-on-board-enriching-data-and-taking-first-decisions")​ | Free
Getting Started and Governance​  | [Presenting SAP LeanIX for Fact Sheet Owners​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fpresenting-sap-leanix-for-fact-sheet-owners "https://learning.sap.com/courses/presenting-sap-leanix-for-fact-sheet-owners") | Free
[Mastering the SAP LeanIX Application Ownership Model![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fmastering-the-sap-leanix-application-ownership-model "https://learning.sap.com/courses/mastering-the-sap-leanix-application-ownership-model") | Free
[SAP LeanIX Roll-out and Adoption Toolkit​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fintroducing-sap-leanix-roll-out-and-adoption-toolkit "https://learning.sap.com/courses/introducing-sap-leanix-roll-out-and-adoption-toolkit") | Free
SAP LeanIX How-Tos​  | [Discovering SAP LeanIX Automations​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fdiscovering-sap-leanix-automations "https://learning.sap.com/courses/discovering-sap-leanix-automations") | Free
[Exploring SAP LeanIX Dashboards![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fexploring-sap-leanix-dashboards "https://learning.sap.com/courses/exploring-sap-leanix-dashboards")​ | Free
[Discovering SAP LeanIX Diagrams​![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fdiscovering-sap-leanix-diagrams "https://learning.sap.com/courses/discovering-sap-leanix-diagrams") | Free
SAP LeanIX Integrations & Configuration​  | [SAP Signavio Integration![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fintegrating-sap-leanix-with-sap-signavio-to-improve-architects-productivity "https://learning.sap.com/courses/integrating-sap-leanix-with-sap-signavio-to-improve-architects-productivity")​ | S-user required (free Enterprise Support package)​
[ServiceNow Integration![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearning.sap.com%2Fcourses%2Fintegrating-sap-leanix-with-servicenow-to-improve-architects-productivity "https://learning.sap.com/courses/integrating-sap-leanix-with-servicenow-to-improve-architects-productivity")​ | S-user required (free Enterprise Support package)


